import sys


SECRET_KEY = 'fake-key'

INSTALLED_APPS = [
    "tests",
]

DATABASES = {
    'default': {
        'ENGINE': 'django.contrib.gis.db.backends.spatialite',
        'NAME': 'db.sqlite3',
    }
}

STATIC_URL = '/static/'


if sys.platform == 'darwin':
    SPATIALITE_LIBRARY_PATH = '/usr/local/lib/mod_spatialite.dylib'



from django.db import models

from location_field.models.plain import PlainLocationField
from location_field.models.spatial import LocationField


class Place(models.Model):
    parent_place = models.ForeignKey('self', blank=True, null=True)
    city = models.CharField(max_length=255)
    location = PlainLocationField(based_fields=[city], zoom=7)


class SpatialPlace(models.Model):
    parent_place = models.ForeignKey('self', blank=True, null=True)
    city = models.CharField(max_length=255)
    location = LocationField(based_fields=[city], zoom=7)
